/*
 *  file      : src/main.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_b2im/lib.h"
#endif

#include <locale.h>
#include <stdlib.h>
#include <stdio.h>

#include "global.h"
#include "configuser.h"



/* gint main (gint argc, gchar *argv[], gchar **envp)
 *
 * argc  designe le nombre darguments transmis au moment du lancement de lexecutable
 * argv  designe le vecteur contenant les differents arguments
 * envp  designe le vecteur contenant les informations sur lenvironnement
 */
gint main( gint argc, gchar *argv[], gchar **envp )
{
	printf( "%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__ );
	printf( "\n" );
	printf( "***************************\n" );
	printf( "%s %s\n", PACKAGE, VERSION );
	printf( "***************************\n" );
	printf( "%s %s compiled at %s %s\n", PACKAGE, VERSION, __DATE__, __TIME__ );
	printf( "Compiler: gcc %s\n", __VERSION__ );
	printf( "***************************\n" );
	g_print( "Gtk version  = %d.%d.%d\n", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION );
	g_print( "Glib version = %d.%d.%d\n", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION );
	g_print( "***************************\n\n" );
#ifdef ENABLE_NLS
	printf( "ENABLE_NLS OK\n" );
	// printf( "	GETTEXT_PACKAGE    = %s\n", GETTEXT_PACKAGE );
	// printf( "	LOCALE_DIR         = %s\n", LOCALE_DIR );
	setlocale( LC_ALL, "" );
	bindtextdomain( GETTEXT_PACKAGE, LOCALE_DIR );
	bind_textdomain_codeset( GETTEXT_PACKAGE, "UTF-8" );
	textdomain( GETTEXT_PACKAGE );
#endif
	gtk_init( &argc, &argv );
	
	configuser_read();

	wind_main_init( NULL );
		
	// NOTEBOOK_GENERATE
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_GENERATE );
	// NOTEBOOK_TO_HOME
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_TO_HOME );
	// NOTEBOOK_GFXBOOT
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_GFXBOOT );
	// NOTEBOOK_PACKAGE
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_PACKAGE );
	// NOTEBOOK_KERNEL
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_KERNEL );
	// NOTEBOOK_DESKTOP
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_DESKTOP );
	// NOTEBOOK_INIT_PACKAGES
	gtk_notebook_set_current_page( GTK_NOTEBOOK(GLADE_GET_OBJECT("notebook_main")), NOTEBOOK_INIT_PACKAGES );

	gtk_widget_hide( GTK_WIDGET(GLADE_GET_OBJECT("box_progressbar")) );
	
	xdg_print_list_config_path();
	xdg_print_list_data_path();
	
	configuser_read_to_textview();

	// ADMINISTRATOR MODE ?
	if( 0 == getuid() ) {
		wind_info_init (
			WindMain_wind_main,
			_("ADMINISTRATOR MODE"),
			  "\n",
			_("   You should not use   "),
			  "\n",
			_("   B2IM under ROOT    !"),
			  "\n",
			"");
	}

	gtk_main();

	exit( EXIT_SUCCESS );
}

