/*
 *  file      : src/pulse.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif
#include <gtk/gtk.h>
#include <glib.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_b2im/lib.h"
#endif

#include "global.h"



typedef struct {
	gboolean	close_request;
	guint		handler_timeout;
	void		(*func_begin_timeout) (void);
	void		(*func_end_timeout) (void);
	void		(*func_begin_thread) (void);
} PULSE;

PULSE pulse;


static gint pulse_timeout( gpointer data )
{
	if( TRUE == pulse.close_request ) {
		g_source_remove( pulse.handler_timeout );
		gtk_widget_hide( GTK_WIDGET(GLADE_GET_OBJECT("box_progressbar")) );
		gtk_widget_show( GTK_WIDGET(GLADE_GET_OBJECT("box_previous_next")) );
		if( pulse.func_end_timeout ) (*pulse.func_end_timeout) ();
		return( FALSE );
	}
	else {
		gtk_progress_bar_pulse( GTK_PROGRESS_BAR(GLADE_GET_OBJECT("progressbar_main")) );
	}
	return( TRUE );
}

void pulse_stop( void )
{
	pulse.close_request = TRUE;
}

static void pulse_thread( void *arg )
{
	if( pulse.func_begin_thread )
		(*pulse.func_begin_thread) ();
	else
		pulse_stop();
	pthread_exit( 0 );
}

void pulse_run( gchar *p_text,
				void *p_func_begin_timeout,
				void *p_func_end_timeout,
				void *p_func_begin_thread
				)
{
	pthread_t	nmr_tid;
	
	pulse.close_request      = FALSE;
	pulse.func_begin_timeout = p_func_begin_timeout;
	pulse.func_end_timeout   = p_func_end_timeout;
	pulse.func_begin_thread  = p_func_begin_thread;
	
	gtk_widget_hide( GTK_WIDGET(GLADE_GET_OBJECT("box_previous_next")) );
	gtk_widget_show( GTK_WIDGET(GLADE_GET_OBJECT("box_progressbar")) );
	while (gtk_events_pending()) gtk_main_iteration();

	if( pulse.func_begin_timeout ) (*pulse.func_begin_timeout) ();
	pulse.handler_timeout = g_timeout_add( 100, pulse_timeout, 0 );
	
	gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_progressbar")), p_text );
  	pthread_create( &nmr_tid, NULL ,(void *)pulse_thread, (void *)NULL );
	
}
